hepstats.hypotests.calculators.basecalculator module
====================================================

.. automodule:: hepstats.hypotests.calculators.basecalculator
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
